# This file was auto-generated by Fern from our API Definition.

import typing

BlockType = typing.Union[
    typing.Literal["text", "heading", "section_heading", "table", "figure", "table_head", "table_cell"], typing.Any
]
